====
Mesh
====

Mesh commands are used to mesh part instances and regions. Mesh commands are also used to assign element sizes, element types, and mesh control parameters.

Classes
-------

Mesh features for Assembly
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshAssembly.MeshAssembly
    :members:
    :special-members: __init__

    .. autoclasstoc::

ElemType
~~~~~~~~

.. autoclass:: abaqus.Mesh.ElemType.ElemType
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshEdge
~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshEdge.MeshEdge
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshEdgeArray
~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshEdgeArray.MeshEdgeArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshElement
~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshElement.MeshElement
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshElementArray
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshElementArray.MeshElementArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

MesherOptions
~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MesherOptions.MesherOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshFace
~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshFace.MeshFace
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshFaceArray
~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshFaceArray.MeshFaceArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshNode
~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshNode.MeshNode
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshNodeArray
~~~~~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshNodeArray.MeshNodeArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshPart
~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshPart.MeshPart
    :members:
    :special-members: __init__

    .. autoclasstoc::

MeshStats
~~~~~~~~~

.. autoclass:: abaqus.Mesh.MeshStats.MeshStats
    :members:
    :special-members: __init__

    .. autoclasstoc::

